@@ -251,6 +251,7 @@ def print_help():
     print "                           with full data reconstruction"
     print "      --https <port>       Port to use for HTTPS server"
     print "      --log-all            Log all article handling (for developers)"
+    print "      --console            Force console logging for OSX app"
     print "      --new                Run a new instance of SABnzbd"
 
 def print_version():
@@ -491,6 +492,18 @@ def print_modules():
         logging.info("pyOpenSSL... NOT found - try apt-get install python-pyopenssl (SSL is optional)")
 
 
+#------------------------------------------------------------------------------
+def all_localhosts():
+    """ Return all unique values of localhost """
+    return ['127.0.0.1']
+    ips = []
+    for item in socket.getaddrinfo('localhost', None):
+        item = item[4][0]
+        if item not in ips:
+            ips.append(item)
+    return ips
+
+
 #------------------------------------------------------------------------------
 def get_webhost(cherryhost, cherryport, https_port):
     """ Determine the webhost address and port,
@@ -613,6 +626,18 @@ def get_webhost(cherryhost, cherryport, https_port):
     return cherryhost, cherryport, browserhost, https_port
 
 
+def attach_server(host, port, cert=None, key=None):
+    """ Define and attach server, optionally HTTPS
+    """
+    http_server = _cpwsgi_server.CPWSGIServer()
+    http_server.bind_addr = (host, port)
+    if cert and key:
+        http_server.ssl_certificate = cert
+        http_server.ssl_private_key = key
+    adapter = _cpserver.ServerAdapter(cherrypy.engine, http_server, http_server.bind_addr)
+    adapter.subscribe()
+
+
 def is_sabnzbd_running(url):
     """ Return True when there's already a SABnzbd instance running.
     """
@@ -773,7 +798,7 @@ def commandline_handler(frozen=True):
                                     'weblogging=', 'server=', 'templates',
                                     'template2', 'browser=', 'config-file=', 'force',
                                     'version', 'https=', 'autorestarted', 'repair', 'repair-all',
-                                    'log-all', 'no-login', 'pid=', 'new', 'sessions',
+                                    'log-all', 'no-login', 'pid=', 'new', 'sessions', 'console',
                                     # Below Win32 Service options
                                     'password=', 'username=', 'startup=', 'perfmonini=', 'perfmondll=',
                                     'interactive', 'wait=',
@@ -847,6 +872,7 @@ def main():
     pid_path = None
     new_instance = False
     force_sessions = False
+    osx_console = False
 
     service, sab_opts, serv_opts, upload_nzbs = commandline_handler()
 
@@ -928,7 +954,11 @@ def main():
         elif opt in ('--new',):
             new_instance = True
         elif opt in ('--sessions',):
+            re_argv.append(opt)
             force_sessions = True
+        elif opt in ('--console',):
+            re_argv.append(opt)
+            osx_console = True
 
     sabnzbd.MY_FULLNAME = os.path.normpath(os.path.abspath(sabnzbd.MY_FULLNAME))
     sabnzbd.MY_NAME = os.path.basename(sabnzbd.MY_FULLNAME)
@@ -946,7 +976,7 @@ def main():
     consoleLogging = consoleLogging and not sabnzbd.DAEMON
 
     # No console logging needed for OSX app
-    noConsoleLoggingOSX = (sabnzbd.DIR_PROG.find('.app/Contents/Resources') > 0)
+    noConsoleLoggingOSX = (not osx_console) and (sabnzbd.DIR_PROG.find('.app/Contents/Resources') > 0)
     if noConsoleLoggingOSX:
         consoleLogging = 1
 
@@ -1273,18 +1303,38 @@ def main():
             logging.warning(Ta('Disabled HTTPS because of missing CERT and KEY files'))
             enable_https = False
 
-        if enable_https:
-            if https_port:
-                # Prepare an extra server for the HTTP port
-                http_server = _cpwsgi_server.CPWSGIServer()
-                http_server.bind_addr = (cherryhost, cherryport)
-                #secure_server.ssl_certificate = https_cert
-                #secure_server.ssl_private_key = https_key
-                adapter = _cpserver.ServerAdapter(cherrypy.engine, http_server, http_server.bind_addr)
-                adapter.subscribe()
-                cherryport = https_port
-            cherrypy.config.update({'server.ssl_certificate' : https_cert,
-                                    'server.ssl_private_key' : https_key })
+    # Determine if this system has multiple definitions for 'localhost'
+    hosts = all_localhosts()
+    multilocal = len(hosts) > 1 and cherryhost in ('localhost', '0.0.0.0')
+
+    # For 0.0.0.0 CherryPy will always pick IPv4, so make sure the secondary localhost is IPv6
+    if multilocal and cherryhost == '0.0.0.0' and hosts[1] == '127.0.0.1':
+        hosts[1] = '::1'
+
+    # The Windows binary requires numeric localhost as primary address
+    if multilocal and cherryhost == 'localhost' and hosts[1] == '127.0.0.1':
+        cherryhost = '::1'
+
+    if enable_https:
+        if https_port:
+            # Extra HTTP port for primary localhost
+            attach_server(cherryhost, cherryport)
+            if multilocal:
+                # Extra HTTP port for secondary localhost
+                attach_server(hosts[1], cherryport)
+                # Extra HTTPS port for secondary localhost
+                attach_server(hosts[1], https_port, https_cert, https_key)
+            cherryport = https_port
+        elif multilocal:
+            # Extra HTTPS port for secondary localhost
+            attach_server(hosts[1], cherryport, https_cert, https_key)
+
+        cherrypy.config.update({'server.ssl_certificate' : https_cert,
+                                'server.ssl_private_key' : https_key })
+    elif multilocal:
+        # Extra HTTP port for secondary localhost
+        attach_server(hosts[1], cherryport)
+
 
     if no_login:
         sabnzbd.cfg.username.set('')
