@@ -23,7 +23,7 @@ import os
 import logging
 import datetime
 import tempfile
-import cPickle
+import cPickle, pickle
 import zipfile
 import glob
 import gzip
@@ -425,14 +425,14 @@ def add_msgid(msgid, pp=None, script=None, cat=None, priority=None, nzbname=None
     if cat and cat.lower()=='default': cat = None
 
     if cfg.newzbin_username() and cfg.newzbin_password():
-        logging.info('Fetching msgid %s from www.newzbin.com', msgid)
-        msg = T('fetching msgid %s from www.newzbin.com') % msgid
+        logging.info('Fetching msgid %s from www.newzbin2.es', msgid)
+        msg = T('fetching msgid %s from www.newzbin2.es') % msgid
 
         future_nzo = NzbQueue.do.generate_future(msg, pp, script, cat=cat, url=msgid, priority=priority, nzbname=nzbname)
 
         MSGIDGrabber.do.grab(msgid, future_nzo)
     else:
-        logging.error(Ta('Error Fetching msgid %s from www.newzbin.com - Please make sure your Username and Password are set'), msgid)
+        logging.error(Ta('Error Fetching msgid %s from www.newzbin2.es - Please make sure your Username and Password are set'), msgid)
 
 
 def add_url(url, pp=None, script=None, cat=None, priority=None, nzbname=None):
@@ -772,7 +772,10 @@ def save_data(data, _id, path, do_pickle = True, silent=False):
     try:
         _f = open(path, 'wb')
         if do_pickle:
-            pickler = cPickle.Pickler(_f, 2)
+            if cfg.use_pickle():
+                pickler = pickle.Pickler(_f, 2)
+            else:
+                pickler = cPickle.Pickler(_f, 2)
             pickler.dump(data)
             _f.flush()
             _f.close()
@@ -804,7 +807,10 @@ def load_data(_id, path, remove=True, do_pickle=True, silent=False):
     try:
         _f = open(path, 'rb')
         if do_pickle:
-            data = cPickle.load(_f)
+            if cfg.use_pickle():
+                data = pickle.load(_f)
+            else:
+                data = cPickle.load(_f)
         else:
             data = _f.read()
         _f.close()
