@@ -25,6 +25,8 @@ import re
 import datetime
 import time
 import cherrypy
+import locale
+locale.setlocale(locale.LC_ALL, "")
 try:
     import win32api, win32file
 except ImportError:
@@ -280,8 +282,13 @@ def _api_addfile(name, output, kwargs):
     # Normal upload will send the nzb in a kw arg called nzbfile
     if name is None or isinstance(name, str) or isinstance(name, unicode):
         name = kwargs.get('nzbfile')
-
-    if name is not None and name.filename and name.value:
+    if hasattr(name, 'getvalue'):
+        #Side effect of next line is that attribute .value is created
+        #which is needed to make add_nzbfile() work
+        size = name.length
+    else:
+        size = len(name.value)
+    if name is not None and name.filename and size:
         sabnzbd.add_nzbfile(name, kwargs.get('pp'), kwargs.get('script'), kwargs.get('cat'),
                             kwargs.get('priority'), kwargs.get('nzbname'))
         return report(output)
@@ -1031,6 +1038,9 @@ def build_queue(web_dir=None, root=None, verbose=False, prim=True, verbose_list=
         slot['cat'] = cat
         slot['mbleft'] = "%.2f" % mbleft
         slot['mb'] = "%.2f" % mb
+        if not output:
+            slot['mb_fmt'] = locale.format('%d', int(mb), True)
+            slot['mbdone_fmt'] = locale.format('%d', int(mb-mbleft), True)
         slot['size'] = format_bytes(bytes)
         slot['sizeleft'] = format_bytes(bytesleft)
         if not Downloader.do.paused and status != 'Paused' and status != 'Fetching' and not found_active:
@@ -1327,7 +1337,7 @@ def rss_qstatus():
         item = Item()
         item.title = name
         if msgid:
-            item.link    = "https://newzbin.com/browse/post/%s/" % msgid
+            item.link    = "https://%s/browse/post/%s/" % (cfg.newzbin_url(), msgid)
         else:
             item.link    = "http://%s:%s/sabnzbd/history" % ( \
             cfg.cherryhost(), cfg.cherryport() )
@@ -1467,6 +1477,7 @@ def build_header(prim):
     header['have_warnings'] = str(sabnzbd.GUIHANDLER.count())
     header['last_warning'] = sabnzbd.GUIHANDLER.last().replace('WARNING', Ta('WARNING:')).replace('ERROR', Ta('ERROR:'))
     header['active_lang'] = cfg.language()
+    header['newzbin_url'] = cfg.newzbin_url()
     if prim:
         header['webdir'] = sabnzbd.WEB_DIR
     else:
