@@ -105,6 +105,7 @@ newzbin_password = OptionPassword('newzbin', 'password')
 newzbin_bookmarks = OptionBool('newzbin', 'bookmarks', False)
 newzbin_unbookmark = OptionBool('newzbin', 'unbookmark', True)
 bookmark_rate = OptionNumber('newzbin', 'bookmark_rate', 60, minval=15, maxval=24*60)
+newzbin_url = OptionStr('newzbin', 'url', 'www.newzbin2.es')
 
 top_only = OptionBool('misc', 'top_only', False)
 autodisconnect = OptionBool('misc', 'auto_disconnect', True)
@@ -213,6 +214,7 @@ api_key = OptionStr('misc', 'api_key', create_api_key())
 nzb_key = OptionStr('misc', 'nzb_key', create_api_key())
 disable_key = OptionBool('misc', 'disable_api_key', False)
 api_warnings = OptionBool('misc', 'api_warnings', True)
+use_pickle = OptionBool('misc', 'use_pickle', False)
 
 #------------------------------------------------------------------------------
 # Set root folders for Folder config-items
