@@ -117,8 +117,9 @@ def convert_filter(text):
         If string starts with re: it's a real regex
         else quote all regex specials, replace '*' by '.*'
     """
-    if text[:3].lower() == 're:':
-        txt = text[3:]
+    text = text.strip().lower()
+    if text.startswith('re:'):
+        txt = text[3:].strip()
     else:
         txt = wildcard_to_re(text)
     try:
@@ -194,6 +195,7 @@ class RSSQueue(object):
                                 if item.get('status', ' ')[0] not in ('D', 'G', 'B', 'X'):
                                     item['status'] = 'X'
                                 if not isinstance(item.get('url'), unicode): item['url'] = ''
+                                item['url'] = item['url'].replace('www.newzbin.com', cfg.newzbin_url())
                                 if not check_str(item.get('cat')): item['cat'] = ''
                                 if not check_str(item.get('orgcat')): item['orgcat'] = ''
                                 if not check_str(item.get('pp')): item['pp'] = '3'
@@ -353,9 +355,9 @@ class RSSQueue(object):
                 except (AttributeError, IndexError):
                     link = None
                     category = ''
-                    logging.error('Incompatible feed %s', uri)
+                    logging.info(Ta('Incompatible feed') + ' ' + uri)
                     logging.info("Traceback: ", exc_info = True)
-                    return 'Incompatible feed'
+                    return T('Incompatible feed')
                 category = latin1(category)
                 # Make sure only latin-1 encodable characters occur
                 atitle = latin1(entry.title)
@@ -547,7 +549,7 @@ class RSSQueue(object):
                     self.jobs[feed][item]['status'] = 'D-'
 
 
-RE_NEWZBIN = re.compile(r'(newz)(bin|xxx).com/browse/post/(\d+)', re.I)
+RE_NEWZBIN = re.compile(r'(newz)(bin|xxx|bin2)\.[\w]+/browse/post/(\d+)', re.I)
 
 def _HandleLink(jobs, link, title, flag, orgcat, cat, pp, script, download, star, order,
                 priority=NORMAL_PRIORITY, rule=0):
@@ -608,7 +610,7 @@ def _get_link(uri, entry):
     link = None
     category = ''
     uri = uri.lower()
-    if 'newzbin.com' in uri or 'newzxxx.com'in uri:
+    if 'newzbin.' in uri or 'newzxxx.'in uri or 'newzbin2.' in uri:
         link = entry.link
         if not (link and '/post/' in link.lower()):
             # Use alternative link
