@@ -1,5 +1,5 @@
 #!/usr/bin/python -OO
-# Copyright 2008-2009 The SABnzbd-Team <team@sabnzbd.org>
+# Copyright 2008-2011 The SABnzbd-Team <team@sabnzbd.org>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -27,12 +27,13 @@ import time
 
 import sabnzbd.utils.kronos as kronos
 import sabnzbd.rss as rss
-import sabnzbd.newzbin as newzbin
+from sabnzbd.newzbin import Bookmarks
 import sabnzbd.downloader
+import sabnzbd.dirscanner
 import sabnzbd.misc
 import sabnzbd.config as config
 import sabnzbd.cfg as cfg
-from sabnzbd.lang import Ta
+from sabnzbd.postproc import PostProcessor
 
 
 __SCHED = None  # Global pointer to Scheduler instance
@@ -46,6 +47,12 @@ def schedule_guard():
     global SCHEDULE_GUARD_FLAG
     SCHEDULE_GUARD_FLAG = True
 
+def pp_pause():
+    PostProcessor.do.paused = True
+
+def pp_resume():
+    PostProcessor.do.paused = False
+
 
 def init():
     """ Create the scheduler and set all required events
@@ -54,19 +61,15 @@ def init():
 
     reset_guardian()
     __SCHED = kronos.ThreadedScheduler()
+    rss_planned = False
 
-    for schedule in cfg.SCHEDULES.get():
+    for schedule in cfg.schedules():
         arguments = []
         argument_list = None
         try:
             m, h, d, action_name = schedule.split()
-        except ValueError:
-            try:
-                m, h, d, action_name, argument_list = schedule.split(None, 4)
-            except ValueError:
-                logging.info('Skipping incorrect schedule "%s"', str(schedule))
-                continue
-
+        except:
+            m, h, d, action_name, argument_list = schedule.split(None, 4)
         if argument_list:
             arguments = argument_list.split()
 
@@ -75,7 +78,7 @@ def init():
             m = int(m)
             h = int(h)
         except:
-            logging.warning(Ta('warn-badSched@3'), action_name, m, h)
+            logging.warning(Ta('Bad schedule %s at %s:%s'), action_name, m, h)
             continue
 
         if d.isdigit():
@@ -87,7 +90,7 @@ def init():
             action = scheduled_resume
             arguments = []
         elif action_name == 'pause':
-            action = sabnzbd.downloader.pause_downloader
+            action = sabnzbd.downloader.Downloader.do.pause
             arguments = []
         elif action_name == 'pause_all':
             action = sabnzbd.pause_all
@@ -98,14 +101,23 @@ def init():
         elif action_name == 'restart':
             action = sabnzbd.restart_program
             arguments = []
+        elif action_name == 'pause_post':
+            action = pp_pause
+        elif action_name == 'resume_post':
+            action = pp_resume
         elif action_name == 'speedlimit' and arguments != []:
-            action = sabnzbd.downloader.limit_speed
+            action = sabnzbd.downloader.Downloader.do.limit_speed
         elif action_name == 'enable_server' and arguments != []:
             action = sabnzbd.enable_server
         elif action_name == 'disable_server' and arguments != []:
             action = sabnzbd.disable_server
+        elif action_name == 'scan_folder':
+            action = sabnzbd.dirscanner.dirscan
+        elif action_name == 'rss_scan':
+            action = rss.run_method
+            rss_planned = True
         else:
-            logging.warning(Ta('warn-badSchedAction@1'), action_name)
+            logging.warning(Ta('Unknown action: %s'), action_name)
             continue
 
         logging.debug("scheduling %s(%s) on days %s at %s:%s", action_name, arguments, d, h, m)
@@ -118,14 +130,15 @@ def init():
                                   kronos.method.sequential, None, None)
 
     # Set RSS check interval
-    interval = cfg.RSS_RATE.get()
-    delay = random.randint(0, interval-1)
-    logging.debug("Scheduling RSS interval task every %s min (delay=%s)", interval, delay)
-    __SCHED.add_interval_task(rss.run_method, "RSS", delay*60, interval*60,
-                                  kronos.method.sequential, None, None)
-    __SCHED.add_single_task(rss.run_method, 'RSS', 15, kronos.method.sequential, None, None)
+    if not rss_planned:
+        interval = cfg.rss_rate()
+        delay = random.randint(0, interval-1)
+        logging.debug("Scheduling RSS interval task every %s min (delay=%s)", interval, delay)
+        __SCHED.add_interval_task(rss.run_method, "RSS", delay*60, interval*60,
+                                      kronos.method.sequential, None, None)
+        __SCHED.add_single_task(rss.run_method, 'RSS', 15, kronos.method.sequential, None, None)
 
-    if cfg.VERSION_CHECK.get():
+    if cfg.version_check():
         # Check for new release, once per week on random time
         m = random.randint(0, 59)
         h = random.randint(0, 23)
@@ -136,19 +149,19 @@ def init():
                                  kronos.method.sequential, [], None)
 
 
-    if cfg.NEWZBIN_BOOKMARKS.get():
-        interval = cfg.BOOKMARK_RATE.get()
+    if cfg.newzbin_bookmarks():
+        interval = cfg.bookmark_rate()
         delay = random.randint(0, interval-1)
         logging.debug("Scheduling Bookmark interval task every %s min (delay=%s)", interval, delay)
-        __SCHED.add_interval_task(newzbin.getBookmarksNow, 'Bookmarks', delay*60, interval*60,
+        __SCHED.add_interval_task(Bookmarks.do.run, 'Bookmarks', delay*60, interval*60,
                                   kronos.method.sequential, None, None)
-        __SCHED.add_single_task(newzbin.getBookmarksNow, 'Bookmarks', 20, kronos.method.sequential, None, None)
+        __SCHED.add_single_task(Bookmarks.do.run, 'Bookmarks', 20, kronos.method.sequential, None, None)
 
 
     # Subscribe to special schedule changes
-    cfg.NEWZBIN_BOOKMARKS.callback(schedule_guard)
-    cfg.BOOKMARK_RATE.callback(schedule_guard)
-    cfg.RSS_RATE.callback(schedule_guard)
+    cfg.newzbin_bookmarks.callback(schedule_guard)
+    cfg.bookmark_rate.callback(schedule_guard)
+    cfg.rss_rate.callback(schedule_guard)
 
 
 def start():
@@ -172,7 +185,7 @@ def restart(force=False):
             SCHEDULE_GUARD_FLAG = False
             stop()
 
-            analyse(sabnzbd.downloader.paused())
+            analyse(sabnzbd.downloader.Downloader.do.paused)
 
             init()
             start()
@@ -184,7 +197,10 @@ def stop():
     global __SCHED
     if __SCHED:
         logging.debug('Stopping scheduler')
-        __SCHED.stop()
+        try:
+            __SCHED.stop()
+        except IndexError:
+            pass
         del __SCHED
         __SCHED = None
 
@@ -208,7 +224,7 @@ def sort_schedules(forward):
     now_hm = int(now[3])*60 + int(now[4])
     now = int(now[6])*24*60 + now_hm
 
-    for schedule in cfg.SCHEDULES.get():
+    for schedule in cfg.schedules():
         parms = None
         try:
             m, h, d, action, parms = schedule.split(None, 4)
@@ -243,6 +259,7 @@ def analyse(was_paused=False):
     """
     paused = None
     paused_all = False
+    pause_post = False
     speedlimit = None
     servers = {}
 
@@ -260,28 +277,33 @@ def analyse(was_paused=False):
         elif action == 'resume':
             paused = False
             paused_all = False
+        elif action == 'pause_post':
+            pause_post = True
+        elif action == 'resume_post':
+            pause_post = False
         elif action == 'speedlimit' and value!=None:
             speedlimit = int(ev[2])
         elif action == 'enable_server':
             try:
                 servers[value] = 1
             except:
-                logging.warning(Ta('warn-schedNoServer@1'), value)
+                logging.warning(Ta('Schedule for non-existing server %s'), value)
         elif action == 'disable_server':
             try:
                 servers[value] = 0
             except:
-                logging.warning(Ta('warn-schedNoServer@1'), value)
+                logging.warning(Ta('Schedule for non-existing server %s'), value)
 
     if not was_paused:
         if paused_all:
             sabnzbd.pause_all()
         else:
             sabnzbd.unpause_all()
-        sabnzbd.downloader.set_paused(paused or paused_all)
+        sabnzbd.downloader.Downloader.do.set_paused_state(paused or paused_all)
 
+    PostProcessor.do.paused = pause_post
     if speedlimit:
-        sabnzbd.downloader.limit_speed(speedlimit)
+        sabnzbd.downloader.Downloader.do.limit_speed(speedlimit)
     for serv in servers:
         try:
             config.get_config('servers', serv).enable.set(servers[serv])
@@ -324,7 +346,7 @@ def plan_resume(interval):
         __PAUSE_END = time.time() + (interval * 60)
         logging.debug('Schedule resume at %s', __PAUSE_END)
         __SCHED.add_single_task(__oneshot_resume, '', interval*60, kronos.method.sequential, [__PAUSE_END], None)
-        sabnzbd.downloader.pause_downloader()
+        sabnzbd.downloader.Downloader.do.pause()
     else:
         __PAUSE_END = None
         sabnzbd.unpause_all()
@@ -363,6 +385,12 @@ def plan_server(action, parms, interval):
     """
     __SCHED.add_single_task(action, '', interval*60, kronos.method.sequential, parms, None)
 
+#------------------------------------------------------------------------------
+def force_rss():
+    """ Add a one-time RSS scan, one second from now
+    """
+    __SCHED.add_single_task(rss.run_method, 'RSS', 1, kronos.method.sequential, None, None)
+
 
 #------------------------------------------------------------------------------
 # Scheduler Guarding system
